<?php

namespace app\controllers;

use app\commands\Clasificadores\TipoClasificador;
use app\commands\Roles;
use app\models\Clasificadorcomun;
use Yii;
use app\models\Persona;
use app\models\PersonaSearch;
use yii\filters\AccessControl;
use yii\helpers\ArrayHelper;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;

/**
 * PersonaController implements the CRUD actions for Persona model.
 */
class PersonaController extends Controller
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access'=>[
                'class'=>AccessControl::classname(),
                'rules'=>[
                    [
                        'allow'=>true,
                        'roles'=>['@']
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    public function beforeAction($event)
    {
        if(!Yii::$app->user->isGuest){
            if(Yii::$app->user->identity->Rol!=Roles::Administrador){
                return $this->redirect(['site/index']);
            }
        }
        return parent::beforeAction($event);
    }

    /**
     * Lists all Persona models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new PersonaSearch();
        $dataProvider = $searchModel->search( Yii::$app->request->queryParams );

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Persona model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Persona model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Persona();



        if (  $model->load( Yii::$app->request->post() )  ) {
            $model->IdCreadoPor = Yii::$app->user->id;
            $model->FechaCreacion = date("Y-m-d H:i:s");
            $model->Activo = true;

            $p = Yii::$app->user->identity;

            $model->save();

            return $this->redirect(['view', 'id' => $model->IdPersona]);
        } else {

            $comboEstadoCivil = Clasificadorcomun::find()->where(["IdTipoClasificadorComun"=>TipoClasificador::EstadoCivil ])->all();
            $comboEstadoCivil = ArrayHelper::map($comboEstadoCivil, 'IdClasificadorComun','Nombre' );

            return $this->render('create', [
                'model' => $model,
                'comboEstadoCivil'=>$comboEstadoCivil,
            ]);
        }
    }

    /**
     * Updates an existing Persona model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) ) {

            $model->IdModificadoPor = Yii::$app->user->id;
            $model->FechaModificacion = date("Y-m-d H:i:s");
            $model->save();
            return $this->redirect(['view', 'id' => $model->IdPersona]);
        } else {

            $comboEstadoCivil = Clasificadorcomun::find()->where(["IdTipoClasificadorComun"=>TipoClasificador::EstadoCivil ])->all();
            $comboEstadoCivil = ArrayHelper::map($comboEstadoCivil, 'IdClasificadorComun','Nombre' );

            $fechaNacimiento =  explode(" ", $model->FechaNacimiento );
            $model->FechaNacimiento = $fechaNacimiento[0];

            return $this->render('update', [
                'model' => $model,
                'comboEstadoCivil'=>$comboEstadoCivil,
            ]);
        }
    }

    /**
     * Deletes an existing Persona model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        //$this->findModel($id)->delete();
        $model = $this->findModel($id);
        $model->Activo=false;
        $model->IdModificadoPor = Yii::$app->user->id;
        $model->FechaModificacion = date("Y-m-d H:i:s");
        $model->save();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Persona model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Persona the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Persona::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
