<?php

namespace app\models;

use Yii;

/**
 * This is the model class for table "persona".
 *
 * @property integer $IdPersona
 * @property string $Nombres
 * @property string $Apellidos
 * @property string $CiNit
 * @property string $Email
 * @property string $Direccion
 * @property string $Telefonos
 * @property integer $IdCreadoPor
 * @property integer $IdcEstadoCivil
 * @property string $FechaNacimiento
 * @property string $FechaCreacion
 * @property integer $IdModificadoPor
 * @property string $FechaModificacion
 * @property boolean $Activo
 *
 * @property Clasificadorcomun $idcEstadoCivil
 * @property User $idCreadoPor
 * @property User $idModificadoPor
 * @property User[] $users
 */
class Persona extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'persona';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['IdCreadoPor', 'IdcEstadoCivil', 'IdModificadoPor'], 'integer'],
            [['FechaNacimiento', 'FechaCreacion', 'FechaModificacion'], 'safe'],
            [['Activo'], 'boolean'],
            [['Nombres', 'Apellidos', 'CiNit'], 'string', 'max' => 45],
            [['Email'], 'string', 'max' => 60],
            [['Direccion'], 'string', 'max' => 150],
            [['Telefonos'], 'string', 'max' => 255],
            [['IdcEstadoCivil'], 'exist', 'skipOnError' => true, 'targetClass' => Clasificadorcomun::className(), 'targetAttribute' => ['IdcEstadoCivil' => 'IdClasificadorComun']],
            [['IdCreadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdCreadoPor' => 'id']],
            [['IdModificadoPor'], 'exist', 'skipOnError' => true, 'targetClass' => User::className(), 'targetAttribute' => ['IdModificadoPor' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'IdPersona' => 'Id Persona',
            'Nombres' => 'Nombres',
            'Apellidos' => 'Apellidos',
            'CiNit' => 'Ci Nit',
            'Email' => 'Email',
            'Direccion' => 'Direccion',
            'Telefonos' => 'Telefonos',
            'IdCreadoPor' => 'Id Creado Por',
            'IdcEstadoCivil' => 'Idc Estado Civil',
            'FechaNacimiento' => 'Fecha Nacimiento',
            'FechaCreacion' => 'Fecha Creacion',
            'IdModificadoPor' => 'Id Modificado Por',
            'FechaModificacion' => 'Fecha Modificacion',
            'Activo' => 'Activo',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdcEstadoCivil()
    {
        return $this->hasOne(Clasificadorcomun::className(), ['IdClasificadorComun' => 'IdcEstadoCivil']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdCreadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdCreadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getIdModificadoPor()
    {
        return $this->hasOne(User::className(), ['id' => 'IdModificadoPor']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getUsers()
    {
        return $this->hasMany(User::className(), ['IdPersona' => 'IdPersona']);
    }
}
